export declare const bpDefaults: {
    xxxs: number;
    xxs: number;
    xs: number;
    s: number;
    sl: number;
    m: number;
    ml: number;
    l: number;
    xl: number;
    xxl: number;
    xxxl: number;
    xxxxl: number;
    xxxxxl: number;
    xxxxxxl: number;
};
interface Ibp {
    readonly [bp: string]: number;
}
export declare const getBpValue: (val: string | number | null | undefined, bp: Ibp) => number;
/**
 * Initialize media query
 *
 * ### Usage
 * ```js
 * import { styled, css } from 'styled-components'
 * import MqInit from 'styled-components-media-query'
 *
 * // initialize
 * const bp = {s: 400, sl: 500, m: 768, ml: 992, l: 1100}
 * const mq = MqInit({ bp })
 *
 * // use like this
 * const ComponentStyled = styled.div`
 *  position: relative;
 *  ${mq('m')(css`
 *    position: absolute;
 *  `)}
 *  ${mq('l')(css`
 *    position: fixed;
 *  `)}
 * `
 * ```
 *
 * @param bp      Pass a breakpoint object to customize the breakpoints you wish to use.
 * @param type    Pass a type string to either use min/max-width or min/max-height.
 * @returns       A styled-component css string.
 */
declare const MqInit: ({ bp, type }?: {
    bp?: {
        xxxs: number;
        xxs: number;
        xs: number;
        s: number;
        sl: number;
        m: number;
        ml: number;
        l: number;
        xl: number;
        xxl: number;
        xxxl: number;
        xxxxl: number;
        xxxxxl: number;
        xxxxxxl: number;
    } | undefined;
    type?: string | undefined;
}) => (min?: string | number | null | undefined, max?: string | number | null | undefined) => (contentCSS: any) => import("styled-components").FlattenSimpleInterpolation;
export declare const mqExec: (min?: string | number | null | undefined, max?: string | number | null | undefined) => (contentCSS: any) => import("styled-components").FlattenSimpleInterpolation;
export default MqInit;
